from setuptools import setup, Extension

try:
    from Cython.Build import cythonize
except ImportError:
    use_cython = False
else:
    use_cython = True


if use_cython:
	ext_modules = cythonize("dtgw/dtw.pyx")
else:
	ext_modules = [Extension("dtgw.dtw", ["dtgw/dtw.c"])]

setup(
	name = "dtgw",
	description = "Computing dtgw-distances between temporal graphs.",
	version = "0.4.1",
	author = "Malte Renken",
	author_email = "m.renken@tu-berlin.de",
	url = "https://www.akt.tu-berlin.de/menue/software",
	packages = ["dtgw"],
	ext_modules = ext_modules,
	zip_safe = True,
	python_requires = ">=3.3, <4",
	install_requires = [
		"numpy >= 1.10",
		"scipy",
		"lapjv",
		# "graph_tool" has to bee installed from https://graph-tool.skewed.de/
	],
	entry_points = {
		"console_scripts": [
			"dtgw = dtgw.main:main"
		]
	}
)
